@@ -646,7 +646,7 @@
 	   :configure-request :circulate-notify :circulate-request :property-notify
 	   :selection-clear :selection-request :selection-notify
 	   :colormap-notify :client-message :mapping-notify
-           :shape-notify :xfree86-vidmode-notify))
+           :shape-notify :xfree86-vidmode-notify :glx-pbuffer-clobber))
 
 (deftype error-key ()
   '(member :access :alloc :atom :colormap :cursor :drawable :font :gcontext :id-choice
